Index: trunk/Ohana/src/addstar/Makefile
===================================================================
--- trunk/Ohana/src/addstar/Makefile	(revision 33963)
+++ trunk/Ohana/src/addstar/Makefile	(revision 34088)
@@ -13,5 +13,5 @@
 
 # programs may add their own internal requirements here
-FULL_CFLAGS   = $(BASE_CFLAGS) -Wall -Werror
+FULL_CFLAGS   = $(BASE_CFLAGS)
 FULL_CPPFLAGS = $(BASE_CPPFLAGS)
 FULL_LDFLAGS  = -lkapa -ldvo -lFITS -lohana $(BASE_LDFLAGS)
Index: trunk/Ohana/src/addstar/src/GetFileMode.c
===================================================================
--- trunk/Ohana/src/addstar/src/GetFileMode.c	(revision 33963)
+++ trunk/Ohana/src/addstar/src/GetFileMode.c	(revision 34088)
@@ -7,10 +7,10 @@
 
   int Naxis;
-  int simple, extend, haveNaxis, haveCTYPE;
+  int simple, extend;
   int havePHOT_VER, haveTARG_VER;
 
   gfits_scan_alt (header, "SIMPLE", "%t", 1, &simple);
-  haveNaxis = gfits_scan (header, "NAXIS",  "%d", 1, &Naxis);
-  haveCTYPE = gfits_scan (header, "CTYPE1", "%s", 1, ctype);
+  int haveNaxis = gfits_scan (header, "NAXIS",  "%d", 1, &Naxis);
+  int haveCTYPE = gfits_scan (header, "CTYPE1", "%s", 1, ctype);
 
   gfits_scan_alt (header, "EXTEND", "%t", 1, &extend);
@@ -22,6 +22,6 @@
   if (havePHOT_VER && haveTARG_VER) return SDSS_OBJ;
 
-  if ((Naxis == 2) || TEXTMODE || !simple) {
-    if (!strcmp (&ctype[4], "-WRP")) {
+  if (haveNaxis && ((Naxis == 2) || TEXTMODE || !simple)) {
+    if (haveCTYPE && !strcmp (&ctype[4], "-WRP")) {
       return MOSAIC_CMP;
     }
Index: trunk/Ohana/src/addstar/src/LoadData.c
===================================================================
--- trunk/Ohana/src/addstar/src/LoadData.c	(revision 33963)
+++ trunk/Ohana/src/addstar/src/LoadData.c	(revision 34088)
@@ -1,4 +1,3 @@
 # include "addstar.h"
-# define DVO_IMAGE_NAME_LEN 128
 
 // XXX this function is somewhat specific to the elixir format output files 
Index: trunk/Ohana/src/addstar/src/LoadDataPMM.c
===================================================================
--- trunk/Ohana/src/addstar/src/LoadDataPMM.c	(revision 33963)
+++ trunk/Ohana/src/addstar/src/LoadDataPMM.c	(revision 34088)
@@ -1,4 +1,3 @@
 # include "addstar.h"
-# define DVO_IMAGE_NAME_LEN 128
 
 /* .asc files look like:
Index: trunk/Ohana/src/addstar/src/ReadStarsSDSS.c
===================================================================
--- trunk/Ohana/src/addstar/src/ReadStarsSDSS.c	(revision 33963)
+++ trunk/Ohana/src/addstar/src/ReadStarsSDSS.c	(revision 34088)
@@ -1,4 +1,4 @@
 # include "addstar.h"
-# define DVO_IMAGE_NAME_LEN 128
+
 int SetSDSSFlags (Stars *star, unsigned int flags1, unsigned int flags2);
 
Index: trunk/Ohana/src/addstar/src/edge_check.c
===================================================================
--- trunk/Ohana/src/addstar/src/edge_check.c	(revision 33963)
+++ trunk/Ohana/src/addstar/src/edge_check.c	(revision 34088)
@@ -4,5 +4,4 @@
 
   double theta1, theta2;
-  double Theta1, Theta2;
 
   theta1 = opening_angle (x1[0], y1[0], x2[0], y2[0], x1[1], y1[1]); 
@@ -17,6 +16,4 @@
   }
 
-  Theta1 = theta1;
-  Theta2 = theta2;
   theta1 = opening_angle (x2[0], y2[0], x1[1], y1[1], x2[1], y2[1]); 
   theta2 = opening_angle (x2[0], y2[0], x1[1], y1[1], x1[0], y1[0]); 
Index: trunk/Ohana/src/addstar/src/get2mass_full.c
===================================================================
--- trunk/Ohana/src/addstar/src/get2mass_full.c	(revision 33963)
+++ trunk/Ohana/src/addstar/src/get2mass_full.c	(revision 34088)
@@ -23,7 +23,7 @@
   star[0][0].measure.theta = ToShortPixels(strtod (ptr, NULL));
 
-  star[2][0].measure.FWx   = star[2][0].measure.FWx   = star[0][0].measure.FWx;
-  star[2][0].measure.FWy   = star[2][0].measure.FWy   = star[0][0].measure.FWy;
-  star[2][0].measure.theta = star[2][0].measure.theta = star[0][0].measure.theta;
+  star[2][0].measure.FWx   = star[1][0].measure.FWx   = star[0][0].measure.FWx;
+  star[2][0].measure.FWy   = star[1][0].measure.FWy   = star[0][0].measure.FWy;
+  star[2][0].measure.theta = star[1][0].measure.theta = star[0][0].measure.theta;
 
   ptr = next2MASSfield (ptr); // designation (skip)
Index: trunk/Ohana/src/addstar/src/load2mass_as_rawdata.c
===================================================================
--- trunk/Ohana/src/addstar/src/load2mass_as_rawdata.c	(revision 33963)
+++ trunk/Ohana/src/addstar/src/load2mass_as_rawdata.c	(revision 34088)
@@ -14,5 +14,5 @@
   int i, j, verbose;
   int Nstars, NSTARS, Ntstars, NTSTARS;
-  int Nbyte, Nextra, Ntotal, offset;
+  int Nbyte, Nextra, offset;
 
   double Rmin, Rmax, Dmin, Dmax;
@@ -37,5 +37,4 @@
 
   Nextra = 0;  // number excess bytes from lsat partial row
-  Ntotal = 0;  // track the total number of bytes read 
   while ((Nbyte = fread (&buffer[Nextra], 1, NBYTE-Nextra, f)) != 0) {
     if (Nbyte == -1) Shutdown ("error reading from raw file %s", filename);
Index: trunk/Ohana/src/addstar/src/load_subpix.c
===================================================================
--- trunk/Ohana/src/addstar/src/load_subpix.c	(revision 33963)
+++ trunk/Ohana/src/addstar/src/load_subpix.c	(revision 34088)
@@ -45,7 +45,7 @@
 
   int bin;
-  double dy, dM;
+  double dM;
 
-  dy = y - (int)(y);
+  // dy = y - (int)(y);
   bin = 5 * (int)(x/100) + (int)(y/100);
   dM = Subpix[bin].dM;
Index: trunk/Ohana/src/addstar/src/loadwise_rawdata.c
===================================================================
--- trunk/Ohana/src/addstar/src/loadwise_rawdata.c	(revision 33963)
+++ trunk/Ohana/src/addstar/src/loadwise_rawdata.c	(revision 34088)
@@ -14,5 +14,5 @@
   int i, j, verbose;
   int Nstars, NSTARS, Ntstars, NTSTARS;
-  int Nbyte, Nextra, Ntotal, offset;
+  int Nbyte, Nextra, offset;
 
   double Rmin, Rmax, Dmin, Dmax;
@@ -37,5 +37,4 @@
 
   Nextra = 0;  // number excess bytes from lsat partial row
-  Ntotal = 0;  // track the total number of bytes read 
   while ((Nbyte = fread (&buffer[Nextra], 1, NBYTE-Nextra, f)) != 0) {
     if (Nbyte == -1) Shutdown ("error reading from raw file %s", filename);
Index: trunk/Ohana/src/addstar/src/resort_catalog.c
===================================================================
--- trunk/Ohana/src/addstar/src/resort_catalog.c	(revision 33963)
+++ trunk/Ohana/src/addstar/src/resort_catalog.c	(revision 34088)
@@ -146,5 +146,5 @@
   int NmeasureTotal = 0;
   int measureOffsetOK = TRUE;
-  for (i = 0; i < catalog[0].Naverage; i++) {
+  for (i = 0; i < Naverage; i++) {
     NmeasureTotal += catalog[0].average[i].Nmeasure;
     if (VERBOSE && !(NmeasureTotal <= catalog[0].Nmeasure)) {
Index: trunk/Ohana/src/addstar/src/sky_tessalation.c
===================================================================
--- trunk/Ohana/src/addstar/src/sky_tessalation.c	(revision 33963)
+++ trunk/Ohana/src/addstar/src/sky_tessalation.c	(revision 34088)
@@ -2,5 +2,4 @@
 # include "assert.h"
 # define iSWAP(X,Y) {int tmp=(X); (X) = (Y); (Y) = tmp;}
-# define DVO_IMAGE_NAME_LEN 128
 
 // we use a static refcoords structure to avoid multiple alloc / init steps

Index: trunk/Ohana/src/addstar/src/get2mass_ops.c
===================================================================
--- trunk/Ohana/src/addstar/src/get2mass_ops.c	(revision 33963)
+++ trunk/Ohana/src/addstar/src/get2mass_ops.c	(revision 34088)
@@ -73,5 +73,4 @@
 
   char *ptr;
-  char Jquality, Hquality, Kquality;
   double J, dJ, H, dH, K, dK;
   e_time time;
@@ -95,5 +94,10 @@
   dK = strtod (ptr, NULL);
 
-  /* filter on the ph_qual flag for this filter (field 19) */
+  // get the time
+  time = get2mass_time (ptr, 20, Nmax - (ptr - line));
+
+# if (0)
+  char Jquality, Hquality, Kquality;
+  /* old code to filter on the ph_qual flag for this filter (field 19) */
   if (SELECT_2MASS_QUALITY != NULL) {
     ptr = skipNbounds (ptr, '|', 3, Nmax - (ptr - line));
@@ -105,4 +109,5 @@
     time = get2mass_time (ptr, 20, Nmax - (ptr - line));
   }
+# endif
 
   // how many bits are being used for the 2mass flags; can we just set photFlags based on them?